pub fn launch(
executable: &str,
library_path: &str,
asar_path: &str,
args: Vec<String>,
detach: bool,
) -> Result<Option<u32>, String>Expand description
Launches an Electron executable with the provided information.
id on Linux: the path to the executable.
id on Windows: the path to the directory containing Update.exe.
library_path: The path to the electron-hook .so or .dll
asar_path: The path to the ASAR file to inject
args: Arguments to pass to the executable
detach: It is recommended to set detach to true to prevent the process from dying when the parent process is closed.